pub struct CliOptions {
pub colors: Option<ColorsArg>,
pub log_level: LoggingLevel,
pub log_kind: LoggingKind,
}Fields
colors: Option<ColorsArg>Set the formatting mode for markup: “off” prints everything as plain text, “force” forces the formatting of markup using ANSI even if the console output is determined to be incompatible
log_level: LoggingLevelThe level of logging. In order, from the most verbose to the least verbose: debug, info, warn, error.
The value none won’t show any logging.
log_kind: LoggingKindHow the log should look like.